import { isValidGraphqlName } from './name.js';
import { normalizeGraphqlValue } from './value.js';
export function normalizeParameterList(parameters) {
    let referencedVariables = new Set();
    const serializedParameters = [];
    for (const [parameterName, parameterValue] of Object.entries(parameters)) {
        if (!isValidGraphqlName(parameterName)) {
            throw new Error(`Parameter name "${parameterName}" is not a valid GraphQL parameter name`);
        }
        const normalizedParameterValue = normalizeGraphqlValue(parameterValue);
        serializedParameters.push(`${parameterName}: ${normalizedParameterValue.serializedValue}`);
        referencedVariables = new Set([...referencedVariables, ...normalizedParameterValue.referencedVariables]);
    }
    return {
        serializedValue: serializedParameters.length > 0 ? `(${serializedParameters.join(', ')})` : '',
        referencedVariables
    };
}
//# sourceMappingURL=parameter-list.js.map